@@ -12,7 +12,7 @@ sub ACTION_authortest {
     my ( $self, @args ) = @_;
 
     $self->depends_on( 'build' );
-    $self->test_files( qw{ t xt } );
+    $self->test_files( qw{ t xt/author } );
     $self->depends_on( 'test' );
 
     return;
